@@ -129,7 +129,7 @@ dev.off()
 }
 if (plotype==2){
 {
-jpeg(file=fileName)
+jpeg(filename=fileName)
 internalBD()
 }
 dev.off()
