@@ -217,7 +217,7 @@ dev.off()
 }
 if (plotype==2){
 {
-jpeg(file=fileName)
+jpeg(filename=fileName)
 internalGenLog()
 }
 dev.off()
