@@ -112,7 +112,7 @@ dev.off()
 }
 if (plotype==2){
 {
-jpeg(file=fileName)
+jpeg(filename=fileName)
 internalLRT()
 }
 dev.off()
